@@ -43,6 +43,12 @@ class Connection(ABCConnection):
         conn: asyncpg.Connection = self.conn
         return await conn.fetch(query, *params, **options)
 
+    async def _fetchmany(self, size: int, query: str, *params, **options) -> t.List[asyncpg.Record]:
+        conn: asyncpg.Connection = self.conn
+        async with conn.transaction():
+            cur = await conn.cursor(query, *params)
+            return await cur.fetch(size)
+
     async def _fetchone(self, query: str, *params, **options) -> t.Optional[asyncpg.Record]:
         conn: asyncpg.Connection = self.conn
         return await conn.fetchrow(query, *params, **options)
@@ -51,6 +57,12 @@ class Connection(ABCConnection):
         conn: asyncpg.Connection = self.conn
         return await conn.fetchval(query, *params, column=column, **options)
 
+    async def _iterate(self, query: str, *params, **options) -> t.AsyncIterator[asyncpg.Record]:
+        conn: asyncpg.Connection = self.conn
+        async with conn.transaction():
+            async for rec in conn.cursor(query, *params):
+                yield rec
+
 
 class Backend(ABCDatabaseBackend):
 
